@@ -1,14 +1,10 @@
-/* $XFree86$ */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 #include "stubs.h"
 
-FontPtr
+weak FontPtr
 find_old_font(FSID id)
 {
     return (FontPtr)NULL;
 }
-
-/* end of file */
